Method: PulpOstreeClient::ContentCommitsApi#read

Defined in:
lib/pulp_ostree_client/api/content_commits_api.rb

#read(ostree_ostree_commit_href, opts = {}) ⇒ OstreeOstreeCommitResponse

Inspect an ostree commit A ViewSet class for OSTree commits.

Parameters:

  • ostree_ostree_commit_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



132
133
134
135
# File 'lib/pulp_ostree_client/api/content_commits_api.rb', line 132

def read(ostree_ostree_commit_href, opts = {})
  data, _status_code, _headers = read_with_http_info(ostree_ostree_commit_href, opts)
  data
end