Method: PulpOstreeClient::OstreeOstreeRemoteResponseHiddenFieldsInner#initialize
- Defined in:
- lib/pulp_ostree_client/models/ostree_ostree_remote_response_hidden_fields_inner.rb
#initialize(attributes = {}) ⇒ OstreeOstreeRemoteResponseHiddenFieldsInner
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/pulp_ostree_client/models/ostree_ostree_remote_response_hidden_fields_inner.rb', line 51 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpOstreeClient::OstreeOstreeRemoteResponseHiddenFieldsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpOstreeClient::OstreeOstreeRemoteResponseHiddenFieldsInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'is_set') self.is_set = attributes[:'is_set'] else self.is_set = nil end end |