Method: PulpOstreeClient::RepositoriesOstreeVersionsApi#read

Defined in:
lib/pulp_ostree_client/api/repositories_ostree_versions_api.rb

#read(ostree_ostree_repository_version_href, opts = {}) ⇒ RepositoryVersionResponse

Inspect a repository version A ViewSet class that represents a single OSTree repository version.

Parameters:

  • ostree_ostree_repository_version_href (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.

Returns:



228
229
230
231
# File 'lib/pulp_ostree_client/api/repositories_ostree_versions_api.rb', line 228

def read(ostree_ostree_repository_version_href, opts = {})
  data, _status_code, _headers = read_with_http_info(ostree_ostree_repository_version_href, opts)
  data
end