Method: PulpOstreeClient::PatchedostreeOstreeRepository#list_invalid_properties
- Defined in:
- lib/pulp_ostree_client/models/patchedostree_ostree_repository.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/pulp_ostree_client/models/patchedostree_ostree_repository.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end invalid_properties end |